@@ -27,7 +27,7 @@ import sys
 import click
 import urwid
 
-from .. import utils
+from .. import icalendar as icalendar_helpers, utils
 from ..khalendar.event import Event
 from ..khalendar.exceptions import ReadOnlyCalendarError
 from . import colors
@@ -733,9 +733,9 @@ class EventColumn(urwid.WidgetWrap):
 
         assert not self.editor
         if external_edit:
-            self.pane.window.loop.screen.stop()
+            self.pane.window.loop.stop()
             text = click.edit(event.raw)
-            self.pane.window.loop.screen.start()
+            self.pane.window.loop.start()
             if text is None:
                 return
             # KeyErrors can occurr here when we destroy DTSTART,
@@ -874,13 +874,13 @@ class EventColumn(urwid.WidgetWrap):
         if end is None:
             start = dt.datetime.combine(date, dt.time(dt.datetime.now().hour))
             end = start + dt.timedelta(minutes=60)
-            event = utils.new_event(
+            event = icalendar_helpers.new_event(
                 dtstart=start, dtend=end, summary='',
                 timezone=self._conf['locale']['default_timezone'],
                 locale=self._conf['locale'],
             )
         else:
-            event = utils.new_event(
+            event = icalendar_helpers.new_event(
                 dtstart=date, dtend=end + dt.timedelta(days=1), summary='',
                 allday=True, locale=self._conf['locale'],
             )
@@ -1061,6 +1061,8 @@ class ClassicView(Pane):
             elistbox.set_focus_date_callback = lambda _: None
         self.calendar = ContainerWidget(calendar)
         self.lwidth = 31 if self._conf['locale']['weeknumbers'] == 'right' else 28
+        if self._conf['view']['frame'] in ["width", "color"]:
+            self.lwidth += 2
         columns = NColumns(
             [(self.lwidth, self.calendar), self.eventscolumn],
             dividechars=0,
